{% load i18n %}
{% load static %}
{% load dashboard_tags %}

{% if content.icon %}
<img src={% static 'gui2/appstore2/images/'|add:content.icon|add:'.svg' %} alt="Notes" />
{% endif %}
<div class="notes p-2 {{ content.class }}" id="{{ content.id }}">
   {% if content.type == 'paragraph' %}
   {% translate content.description %}
   {% elif content.type == "list" %}
   <ul>
     {% for l in content.description %}
     {% if l %}
     <li style="list-style-type: disc;">{% translate l %} </li>
       {% endif %}
     {% endfor %}
   </ul>
   {% endif %}
</div>
